==> thux.payment-1.0.0.tar.gz: thux.payment-1.0.0/thux/payment/models.py <==
# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


class PaymentForm(DateModel, UserModel, StatusModel, OrderedModel):
    code = models.CharField(
        primary_key=True,
        max_length=25,
        verbose_name=_("code"),
    )
    name = models.CharField(
        unique=True,
        max_length=100,
        db_index=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )
    fee = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        default=0,
        verbose_name=_("fee"),
    )
    discount = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        default=0,
        verbose_name=_("discount"),
    )

    class Meta:
        verbose_name = _("payment form")
        verbose_name_plural = _("payment forms")
        ordering = ('code',)

    def __unicode__(self):
        return u"{} - {}".format(self.code, self.name)


class PaymentInstallment(DateModel, UserModel, StatusModel, OrderedModel):
    payment_form = models.ForeignKey(
        'PaymentForm',
        related_name="installments",
        verbose_name=_("payment form"),
    )
    code = models.CharField(
        primary_key=True,
        blank=True,
        max_length=35,
        verbose_name=_("code"),
    )
    name = models.CharField(
        unique=True,
        blank=True,
        max_length=110,
        db_index=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )
    amount = models.IntegerField(
        default=100,
        verbose_name=_("amount %"),
    )
    days = models.IntegerField(
        default=0,
        verbose_name=_("days"),
    )
    end_month = models.BooleanField(
        db_index=True,
        default=False,  # added explicitly since 1.6 changed it to None
        verbose_name=_("end month"),
    )
    # Giorni aggiuntivi oltre il fine mese.
    # Viene utilizzato solo se end_month è uguale a True e viene sommato alla
    # data di scadenza calcolata
    days_end_month = models.IntegerField(
        default=0,
        verbose_name=_("days after end month"),
    )
    discount = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0.00,
        verbose_name=_("discount %"),
    )
    fee = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0.00,
        verbose_name=_("fee %"),
    )

    def save(self, **kw):
        if not self.code:
            self.code = "{}_{}_{}".format(
                self.payment_form.code, self.amount, self.days
            )
        if not self.name:
            self.name = unicode(
                "Codice Pagamento: {} {}% {} gg."
            ).format(
                self.payment_form.code, self.amount, self.days
            )
        super(PaymentInstallment, self).save(**kw)

    class Meta:
        verbose_name = _("payment installment")
        verbose_name_plural = _("payment installments")
        ordering = ('code',)

    def __unicode__(self):
        return u"{} - {}".format(self.code, self.name)

    def get_full_name(self):
        return u"{} {}".format(self.payment_form.name, self.days)

    full_name = property(get_full_name)

==> thux.payment-2.0.2.tar.gz: thux.payment-2.0.2/thux/payment/models.py <==
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
from six import python_2_unicode_compatible
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


@python_2_unicode_compatible
class PaymentForm(DateModel, UserModel, StatusModel, OrderedModel):
    code = models.CharField(
        primary_key=True,
        max_length=25,
        verbose_name=_("code"),
    )
    name = models.CharField(
        unique=True,
        max_length=100,
        db_index=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )
    fee = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        default=0,
        verbose_name=_("fee"),
    )
    discount = models.DecimalField(
        max_digits=9,
        decimal_places=2,
        default=0,
        verbose_name=_("discount"),
    )

    class Meta:
        verbose_name = _("payment form")
        verbose_name_plural = _("payment forms")
        ordering = ('ordering', 'code',)
        permissions = (
            ("list_paymentform", "Can list payment form"),
            ("detail_paymentform", "Can detail payment form"),
            ("disable_paymentform", "Can disable payment form"),
        )

    def __str__(self):
        return "{} - {}".format(self.code, self.name)


@python_2_unicode_compatible
class PaymentInstallment(DateModel, UserModel, StatusModel, OrderedModel):
    payment_form = models.ForeignKey(
        'PaymentForm',
        related_name="installments",
        verbose_name=_("payment form"),
    )
    code = models.CharField(
        primary_key=True,
        max_length=255,
        verbose_name=_("code"),
    )
    name = models.CharField(
        unique=True,
        blank=True,
        max_length=110,
        db_index=True,
        verbose_name=_("name"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("description"),
    )
    amount = models.IntegerField(
        default=100,
        verbose_name=_("amount %"),
    )
    days = models.IntegerField(
        default=0,
        verbose_name=_("days"),
    )
    end_month = models.BooleanField(
        db_index=True,
        default=False,  # added explicitly since 1.6 changed it to None
        verbose_name=_("end month"),
    )
    # Giorni aggiuntivi oltre il fine mese.
    # Viene utilizzato solo se end_month è uguale a True e viene sommato alla
    # data di scadenza calcolata
    days_end_month = models.IntegerField(
        default=0,
        verbose_name=_("days after end month"),
    )
    discount = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0.00,
        verbose_name=_("discount %"),
    )
    fee = models.DecimalField(
        max_digits=4,
        decimal_places=2,
        default=0.00,
        verbose_name=_("fee %"),
    )

    class Meta:
        verbose_name = _("payment installment")
        verbose_name_plural = _("payment installments")
        ordering = ('ordering', 'code',)
        permissions = (
            ("list_paymentinstallment", "Can list payment installment"),
            ("detail_paymentinstallment", "Can detail payment installment"),
            ("disable_paymentinstallment", "Can disable payment installment"),
        )

    def __str__(self):
        return "{} - {}".format(self.code, self.name)

    def save(self, **kw):
        if not self.code:
            self.code = "{}_{}_{}".format(
                self.payment_form.code, self.amount, self.days
            )
        if not self.name:
            self.name = "Codice Pagamento: {} {}% {} gg.".format(
                self.payment_form.code, self.amount, self.days
            )
        super(PaymentInstallment, self).save(**kw)

    def get_full_name(self):
        return "{} {}".format(self.payment_form.name, self.days)

    full_name = property(get_full_name)
